@@ -133,4 +133,9 @@ def visualize_map_sample(areas_to_points, clusters, min_supp, features, max_samp
             folium.Circle(location=[point[1], point[0]], popup = str(point),
                             color=colors_to_use[index], radius=10).add_to(hmap)
             
-    return hmap
\ No newline at end of file
+    return hmap
+
+    """
+    Dejar matriz implicita no más
+    Bag of parameters
+    """
\ No newline at end of file
